package core.services.ntfy;


import org.quartz.*;
import org.quartz.impl.StdSchedulerFactory;

import java.time.LocalDateTime;
import java.time.ZoneId;
import java.util.Date;

public class TaskSchedulingService {

    public static void scheduleStartingTask(String taskName) throws SchedulerException {
        Scheduler scheduler = StdSchedulerFactory.getDefaultScheduler();
        scheduler.start();

        JobDetail job = JobBuilder.newJob(NtfyTaskStartNotification.class).build();
        job.getJobDataMap().put("task", taskName);

        Trigger immediatly = TriggerBuilder.newTrigger().startNow().build();

        scheduler.scheduleJob(job, immediatly);
    }

   public static void scheduleTask() throws SchedulerException {
       Scheduler scheduler = StdSchedulerFactory.getDefaultScheduler();
       scheduler.start();

       JobDetail job = JobBuilder.newJob(NtfyTask.class).build();

       job.getJobDataMap().put("data", "A simple Job 1 Message");

       LocalDateTime executionTime = LocalDateTime.of(2024, 3, 14, 9, 18); // Example: March 15, 2024, 10:00 AM

       Trigger trigger = TriggerBuilder.newTrigger()
               .withIdentity("trigger1", "Group 1")
               .startAt(calculateDelayInMillis(executionTime)).build();
       Trigger trigger2 = TriggerBuilder.newTrigger()
               .withIdentity("trigger2", "Group 1")
               .startAt(calculateDelayInMillis(executionTime.plusMinutes(1))).build();

       Trigger immediatly = TriggerBuilder.newTrigger().withIdentity("Immediately", "Group 1").startNow().build();

       scheduler.scheduleJob(job, immediatly);
   }

    private static Date calculateDelayInMillis(LocalDateTime executionTime) {
        return  Date.from(executionTime.atZone(ZoneId.systemDefault()).toInstant());
    }
}
